********
Examples
********


Running |popstar|
=================

Here's an example of running Python |popstar|.


.. code-block:: python

	from gaussdriver import driver
	gstruc = driver.driver('mycube.fits',368,8)
